@@ -5,14 +5,14 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import cdktf._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "@cdktf/provider-null", "0.0.6", __name__[0:-6], "provider-null@0.0.6.jsii.tgz"
+    "@cdktf/provider-null", "0.0.14", __name__[0:-6], "provider-null@0.0.14.jsii.tgz"
 )
 
 __all__ = [
